#Created by: Melissa Trayhan, Rochester Center For Health Informatics
#This file reads in trimmed claims data and sorts the data accoridng to the netowrk type to be created

#Use subsetter.pl before running this script to get the claims data in the correct format.
#data format:
#Patient id [0], Date [1], Organization NPI [2], Attending NPI [3], Operating NPI [4]

#!/usr/bin/perl
use strict;
use warnings;

#specify claims data and check if it is a file
my $file = $ARGV[0] or die "Please state the CSV filename as arg 1\n";
unless (-f $file) {
  die "Not a valid file! Try again\n";
}

#select which type of network to create/sort: organization to organization, attending provider to attening provider, or operating provider to operating provider
my $npi_type = $ARGV[1] or die "Please state the npi type as arg 2, use ORG for organization, PRV for provider or OPR for operating\n";
my $npi_col;

if ($npi_type eq "ORG" || $npi_type eq "org") {
  $npi_col = 2;
}
elsif ($npi_type eq "PRV" || $npi_type eq "prv") {
  $npi_col = 3;
}
elsif ($npi_type eq "OPR" || $npi_type eq "opr") {
  $npi_col = 4;
}
else {
  die "Please state the npi type as arg 2, use ORG for organization, PRV for provider or OPR for operating\n";
}

my $result_file = $ARGV[2] or die "Please state the results CSV filename as arg 3\n";

#open and import claims data
open(my $data, '<', $file) or die "Could not open '$file' $!\n";

my @matrix;

while (my $line = <$data>) {
  chomp $line;
  my @temp = split "," , $line;
  push @matrix, \@temp;
 }

close $data;

#sort data based on user selected network type
my @sorted = sort { $a->[0] <=> $b->[0] || $a->[1] <=> $b->[1] || defined $a->[$npi_col] <=> defined $b->[$npi_col] } @matrix;
 
open(my $fh, '>', $result_file) or die "Could not open results file, $!\n";

for (my $x = 0; $x < @sorted; $x++ ) {
  if ($sorted[$x][4]) {
    print $fh "$sorted[$x][0],$sorted[$x][1],$sorted[$x][2],$sorted[$x][3],$sorted[$x][4]\n";
  }
  else {
    print $fh "$sorted[$x][0],$sorted[$x][1],$sorted[$x][2],$sorted[$x][3],\n";
  }
}


close $data;
close $fh;
